@@ -15,17 +15,17 @@
 import mock
 import ujson as json
 
-from monasca_log_api.api import headers
-from monasca_log_api.reference.v2 import logs as v2_logs
-from monasca_log_api.reference.v3 import logs as v3_logs
+from monasca_log_api.app.controller.api import headers
+from monasca_log_api.app.controller.v2 import logs as v2_logs
+from monasca_log_api.app.controller.v3 import logs as v3_logs
 from monasca_log_api.tests import base
 
 
 class TestApiSameV2V3Output(base.BaseApiTestCase):
 
     # noinspection PyProtectedMember
-    @mock.patch('monasca_log_api.reference.common.'
-                'log_publisher.producer.KafkaProducer')
+    @mock.patch('monasca_log_api.app.base.log_publisher.'
+                'producer.KafkaProducer')
     def test_send_identical_messages(self, _):
         # mocks only log publisher, so the last component that actually
         # sends data to kafka
@@ -66,11 +66,11 @@ class TestApiSameV2V3Output(base.BaseApiTestCase):
             ]
         }
 
-        self.api.add_route('/v2.0', v2)
-        self.api.add_route('/v3.0', v3)
+        self.app.add_route('/v2.0', v2)
+        self.app.add_route('/v3.0', v3)
 
         self.simulate_request(
-            '/v2.0',
+            path='/v2.0',
             method='POST',
             headers={
                 headers.X_ROLES.name: roles,
@@ -78,19 +78,17 @@ class TestApiSameV2V3Output(base.BaseApiTestCase):
                 headers.X_APPLICATION_TYPE.name: component,
                 headers.X_TENANT_ID.name: tenant_id,
                 'Content-Type': 'application/json',
-                'Content-Length': '100'
             },
             body=json.dumps(v2_body)
         )
 
         self.simulate_request(
-            '/v3.0',
+            path='/v3.0',
             method='POST',
             headers={
                 headers.X_ROLES.name: roles,
                 headers.X_TENANT_ID.name: tenant_id,
                 'Content-Type': 'application/json',
-                'Content-Length': '100'
             },
             body=json.dumps(v3_body)
         )
