@@ -13,9 +13,8 @@
 # under the License.
 
 import falcon
-import ujson as json
 
-from monasca_log_api.reference import versions
+from monasca_log_api.app.controller import versions
 from monasca_log_api.tests import base
 
 
@@ -24,29 +23,27 @@ def _get_versioned_url(version_id):
 
 
 class TestApiVersions(base.BaseApiTestCase):
-    def __init__(self, *args, **kwargs):
-        self.versions = None
-        super(TestApiVersions, self).__init__(*args, **kwargs)
 
-    def before(self):
-        super(TestApiVersions, self).before()
+    def setUp(self):
+        super(TestApiVersions, self).setUp()
         self.versions = versions.Versions()
-        self.api.add_route("/version/", self.versions)
-        self.api.add_route("/version/{version_id}", self.versions)
+        self.app.add_route("/", self.versions)
+        self.app.add_route("/version/", self.versions)
+        self.app.add_route("/version/{version_id}", self.versions)
 
     def test_should_fail_for_unsupported_version(self):
         unsupported_version = 'v5.0'
         uri = _get_versioned_url(unsupported_version)
 
-        self.simulate_request(
-            uri,
+        res = self.simulate_request(
+            path=uri,
             method='GET',
             headers={
                 'Content-Type': 'application/json'
             }
         )
 
-        self.assertEqual(falcon.HTTP_400, self.srmock.status)
+        self.assertEqual(falcon.HTTP_400, res.status)
 
     def test_should_return_all_supported_versions(self):
 
@@ -77,40 +74,46 @@ class TestApiVersions(base.BaseApiTestCase):
                 self.assertIn('rel', link)
                 key = link.get('rel')
                 self.assertIn(key, expected_links_keys)
+                href = link.get('href')
+                self.assertTrue(href.startswith(expected_url))
 
         expected_versions = 'v2.0', 'v3.0'
         expected_links_keys = 'self', 'version', 'healthcheck'
+        expected_protocol = 'http'
+        expected_host = 'fakehost.com'
+        expected_url = '{}://{}'.format(expected_protocol, expected_host)
 
-        res = self.simulate_request(
-            '/version',
-            method='GET',
-            headers={
-                'Content-Type': 'application/json'
-            },
-            decode='utf-8'
-        )
-        self.assertEqual(falcon.HTTP_200, self.srmock.status)
+        for expected_path in ['/', '/version']:
+            res = self.simulate_request(
+                path=expected_path,
+                protocol=expected_protocol,
+                host=expected_host,
+                method='GET',
+                headers={
+                    'Content-Type': 'application/json'
+                }
+            )
+            self.assertEqual(falcon.HTTP_200, res.status)
 
-        response = json.loads(res)
+            response = res.json
 
-        _check_elements()
-        _check_global_links()
+            _check_elements()
+            _check_global_links()
 
     def test_should_return_expected_version_id(self):
         expected_versions = 'v2.0', 'v3.0'
         for expected_version in expected_versions:
             uri = _get_versioned_url(expected_version)
             res = self.simulate_request(
-                uri,
+                path=uri,
                 method='GET',
                 headers={
                     'Content-Type': 'application/json'
                 },
-                decode='utf-8'
             )
-            self.assertEqual(falcon.HTTP_200, self.srmock.status)
+            self.assertEqual(falcon.HTTP_200, res.status)
 
-            response = json.loads(res)
+            response = res.json
             self.assertIn('elements', response)
             self.assertIn('links', response)
 
